@@ -171,19 +171,19 @@ class CrabNet(nn.Module):
         lr : float, optional
             Learning rate, by default 1e-3
         betas : tuple, optional
-            [description], by default (0.9, 0.999)
+            Coefficients on gradient and squared gradient during ``Lamb`` optimization, by default (0.9, 0.999)
         eps : float, optional
-            [description], by default 1e-6
+            Value added to the denominator during ``Lamb`` optimization, by default 1e-6
         weight_decay : float, optional
-            [description], by default 0
+            L2 penalty in ``Lamb``, by default 0
         adam : bool, optional
-            Whether to constrain the Lamb model to be the Adam model, by default False
+            Whether to constrain the ``Lamb`` model to be the Adam model, by default False
         min_trust : float, optional
             [description], by default None
         alpha : float, optional
-            float, by default 0.5
+            ``Lookahead`` "slow update" rate, by default 0.5
         k : int, optional
-            [description], by default 6
+            Number of ``Lookahead`` steps, by default 6
         base_lr : float, optional
             Base learning rate, by default 1e-4
         max_lr : float, optional
@@ -638,9 +638,14 @@ class CrabNet(nn.Module):
                 pred_v, true_v = self.predict(loader=self.data_loader, return_true=True)
                 if np.any(np.isnan(pred_v)):
                     warn(
-                        "NaN values found in `pred_v`. Replacing with DummyRegressor() values (i.e. mean of training targets)."
+                        "NaN values found in `pred_v`. Replacing with DummyRegressor() values (i.e. mean of training targets)"
                     )
-                    pred_v = np.nan_to_num(pred_v)
+                    avg = np.mean(true_v)
+                    if np.isnan(avg):
+                        raise ValueError(
+                            "Found NaN values in training data. Remove or replace via `np.nan_to_num` before running."
+                        )
+                    pred_v = np.nan_to_num(pred_v, nan=avg)
                 mae_v = mean_absolute_error(true_v, pred_v)
                 # https://github.com/pytorch/contrib/blob/master/torchcontrib/optim/swa.py
                 # https://pytorch.org/blog/pytorch-1.6-now-includes-stochastic-weight-averaging/
@@ -758,9 +763,25 @@ class CrabNet(nn.Module):
             loader=self.train_loader,
             return_true=True,
         )
+
+        if np.any(np.isnan(pred_t)):
+            warn(
+                "NaN values found in `pred_t`. Replacing with DummyRegressor() values (i.e. mean of training targets)."
+            )
+            avg = np.mean(true_t)
+            pred_t = np.nan_to_num(pred_t, nan=avg)
+
         mae_t = mean_absolute_error(true_t, pred_t)
         self.loss_curve["train"].append(mae_t)
         pred_v, true_v = self.predict(loader=self.data_loader, return_true=True)
+
+        if np.any(np.isnan(pred_v)):
+            warn(
+                "NaN values found in `pred_v`. Replacing with DummyRegressor() values (i.e. mean of training targets) using `np.nanmean`."
+            )
+            avg = np.nanmean(true_v)
+            pred_v = np.nan_to_num(pred_v, nan=avg)
+
         mae_v = mean_absolute_error(true_v, pred_v)
         self.loss_curve["val"].append(mae_v)
         epoch_str = f"Epoch: {epoch}/{epochs} ---"
